﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace HierarchyNavigator_Sample
{
    /// <summary>
    /// Interaction logic for UserControl1.xaml
    /// </summary>
    public partial class UserControl1 : UserControl
    {
        public UserControl1()
        {
            InitializeComponent();

            this.DataContext = this;

            HierarchyItem root = new HierarchyItem("My Files");

            HierarchyItem item1 = new HierarchyItem("Item1");
            item1.ContentString = @"C:\";
            root.HierarchyItems.Add(item1);

            HierarchyItem item2 = new HierarchyItem("Item2");
            item2.ContentString = @"D:\";
            root.HierarchyItems.Add(item2);

            ItemsColl = new ObservableCollection<HierarchyItem>();
            ItemsColl.Add(root);

            hierarchyNavigator2.HierarchyNavigatorSelectedItemChanged += HierarchyNavigator2_HierarchyNavigatorSelectedItemChanged;
        }

        
        private void HierarchyNavigator2_HierarchyNavigatorSelectedItemChanged(object sender, Syncfusion.Windows.Tools.Controls.HierarchyNavigatorSelectedItemChangedEventArgs e)
        {
            if (hierarchyNavigator2.SelectedItem == null) return;

            HierarchyItem selItm = hierarchyNavigator2.SelectedItem as HierarchyItem;
            string[] dirs = Directory.GetDirectories(selItm.ContentString, "*", SearchOption.TopDirectoryOnly);

            foreach (string dir in dirs)
            {
                selItm.HierarchyItems.Add(new HierarchyItem(dir));
            }
        }

        public HierarchyItem SelItem
        {
            get { return (HierarchyItem)GetValue(SelItemProperty); }
            set { SetValue(SelItemProperty, value); }
        }

        public static readonly DependencyProperty SelItemProperty =
            DependencyProperty.Register("SelItem", typeof(HierarchyItem), typeof(UserControl1), new PropertyMetadata(null));



        public ObservableCollection<HierarchyItem> ItemsColl
        {
            get { return (ObservableCollection<HierarchyItem>)GetValue(ItemsCollProperty); }
            set { SetValue(ItemsCollProperty, value); }
        }

        public static readonly DependencyProperty ItemsCollProperty =
            DependencyProperty.Register("ItemsColl", typeof(ObservableCollection<HierarchyItem>), typeof(UserControl1), 
                new PropertyMetadata(null, new PropertyChangedCallback(OnItemsCollChanged)));

        private static void OnItemsCollChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            UserControl1 me = d as UserControl1;

            var old = e.OldValue as ObservableCollection<HierarchyItem>;

            if (old != null)
                old.CollectionChanged -= me.OnItemChanged;

            var n = e.NewValue as ObservableCollection<HierarchyItem>;

            if (n != null)
                n.CollectionChanged += me.OnItemChanged;
        }

        private void OnItemChanged(object sender, NotifyCollectionChangedEventArgs e)
        {

        }
    }

    

    public class HierarchicalItemsSource : ObservableCollection<HierarchyItem>
    {
        public HierarchicalItemsSource()
        {
        }
    }

    public class HierarchyItem
    {
        public string ContentString { get; set; }
        public HierarchyItem(string content)
        {
            this.ContentString = content;
            HierarchyItems = new ObservableCollection<HierarchyItem>();
        }
        private ObservableCollection<HierarchyItem> itemsObservableCollection;
        public ObservableCollection<HierarchyItem> HierarchyItems
        {
            get { return itemsObservableCollection; }
            set
            {
                if (itemsObservableCollection != value)
                {
                    itemsObservableCollection = value;
                }
            }
        }
    }
   
}
